@@ -1,6 +1,9 @@
+import enum
+import json
 import textwrap
 from typing import Any, Dict, List, Optional, Tuple
 
+from snowflake import snowpark
 from snowflake.ml._internal.utils import (
     identifier,
     query_result_checker,
@@ -11,6 +14,17 @@ from snowflake.snowpark import dataframe, functions as F, types as spt
 from snowflake.snowpark._internal import utils as snowpark_utils
 
 
+class ServiceStatus(enum.Enum):
+    UNKNOWN = "UNKNOWN"  # status is unknown because we have not received enough data from K8s yet.
+    PENDING = "PENDING"  # resource set is being created, can't be used yet
+    READY = "READY"  # resource set has been deployed.
+    DELETING = "DELETING"  # resource set is being deleted
+    FAILED = "FAILED"  # resource set has failed and cannot be used anymore
+    DONE = "DONE"  # resource set has finished running
+    NOT_FOUND = "NOT_FOUND"  # not found or deleted
+    INTERNAL_ERROR = "INTERNAL_ERROR"  # there was an internal service error.
+
+
 class ServiceSQLClient(_base._BaseSQLClient):
     def build_model_container(
         self,
@@ -30,20 +44,21 @@ class ServiceSQLClient(_base._BaseSQLClient):
     ) -> None:
         actual_image_repo_database = image_repo_database_name or self._database_name
         actual_image_repo_schema = image_repo_schema_name or self._schema_name
-        fq_model_name = self.fully_qualified_object_name(database_name, schema_name, model_name)
-        fq_image_repo_name = "/" + "/".join(
-            [
-                actual_image_repo_database.identifier(),
-                actual_image_repo_schema.identifier(),
-                image_repo_name.identifier(),
-            ]
+        actual_model_database = database_name or self._database_name
+        actual_model_schema = schema_name or self._schema_name
+        fq_model_name = self.fully_qualified_object_name(actual_model_database, actual_model_schema, model_name)
+        fq_image_repo_name = identifier.get_schema_level_object_identifier(
+            actual_image_repo_database.identifier(),
+            actual_image_repo_schema.identifier(),
+            image_repo_name.identifier(),
         )
-        is_gpu = gpu is not None
+        is_gpu_str = "TRUE" if gpu else "FALSE"
+        force_rebuild_str = "TRUE" if force_rebuild else "FALSE"
         query_result_checker.SqlResultValidator(
             self._session,
             (
                 f"CALL SYSTEM$BUILD_MODEL_CONTAINER('{fq_model_name}', '{version_name}', '{compute_pool_name}',"
-                f" '{fq_image_repo_name}', '{is_gpu}', '{force_rebuild}', '', '{external_access_integration}')"
+                f" '{fq_image_repo_name}', '{is_gpu_str}', '{force_rebuild_str}', '', '{external_access_integration}')"
             ),
             statement_params=statement_params,
         ).has_dimensions(expected_rows=1, expected_cols=1).validate()
@@ -54,12 +69,12 @@ class ServiceSQLClient(_base._BaseSQLClient):
         stage_path: str,
         model_deployment_spec_file_rel_path: str,
         statement_params: Optional[Dict[str, Any]] = None,
-    ) -> None:
-        query_result_checker.SqlResultValidator(
-            self._session,
-            f"CALL SYSTEM$DEPLOY_MODEL('@{stage_path}/{model_deployment_spec_file_rel_path}')",
-            statement_params=statement_params,
-        ).has_dimensions(expected_rows=1, expected_cols=1).validate()
+    ) -> Tuple[str, snowpark.AsyncJob]:
+        async_job = self._session.sql(
+            f"CALL SYSTEM$DEPLOY_MODEL('@{stage_path}/{model_deployment_spec_file_rel_path}')"
+        ).collect(block=False, statement_params=statement_params)
+        assert isinstance(async_job, snowpark.AsyncJob)
+        return async_job.query_id, async_job
 
     def invoke_function_method(
         self,
@@ -74,12 +89,20 @@ class ServiceSQLClient(_base._BaseSQLClient):
         statement_params: Optional[Dict[str, Any]] = None,
     ) -> dataframe.DataFrame:
         with_statements = []
+        actual_database_name = database_name or self._database_name
+        actual_schema_name = schema_name or self._schema_name
+
+        function_name = identifier.concat_names([service_name.identifier(), "_", method_name.identifier()])
+        fully_qualified_function_name = identifier.get_schema_level_object_identifier(
+            actual_database_name.identifier(),
+            actual_schema_name.identifier(),
+            function_name,
+        )
+
         if len(input_df.queries["queries"]) == 1 and len(input_df.queries["post_actions"]) == 0:
             INTERMEDIATE_TABLE_NAME = "SNOWPARK_ML_MODEL_INFERENCE_INPUT"
             with_statements.append(f"{INTERMEDIATE_TABLE_NAME} AS ({input_df.queries['queries'][0]})")
         else:
-            actual_database_name = database_name or self._database_name
-            actual_schema_name = schema_name or self._schema_name
             tmp_table_name = snowpark_utils.random_name_for_temp_object(snowpark_utils.TempObjectType.TABLE)
             INTERMEDIATE_TABLE_NAME = identifier.get_schema_level_object_identifier(
                 actual_database_name.identifier(),
@@ -104,7 +127,7 @@ class ServiceSQLClient(_base._BaseSQLClient):
         sql = textwrap.dedent(
             f"""{with_sql}
                 SELECT *,
-                    {service_name.identifier()}_{method_name.identifier()}({args_sql}) AS {INTERMEDIATE_OBJ_NAME}
+                    {fully_qualified_function_name}({args_sql}) AS {INTERMEDIATE_OBJ_NAME}
                 FROM {INTERMEDIATE_TABLE_NAME}"""
         )
 
@@ -127,3 +150,47 @@ class ServiceSQLClient(_base._BaseSQLClient):
             output_df._statement_params = statement_params  # type: ignore[assignment]
 
         return output_df
+
+    def get_service_logs(
+        self,
+        *,
+        service_name: str,
+        instance_id: str = "0",
+        container_name: str,
+        statement_params: Optional[Dict[str, Any]] = None,
+    ) -> str:
+        system_func = "SYSTEM$GET_SERVICE_LOGS"
+        rows = (
+            query_result_checker.SqlResultValidator(
+                self._session,
+                f"CALL {system_func}('{service_name}', '{instance_id}', '{container_name}')",
+                statement_params=statement_params,
+            )
+            .has_dimensions(expected_rows=1, expected_cols=1)
+            .validate()
+        )
+        return str(rows[0][system_func])
+
+    def get_service_status(
+        self,
+        *,
+        service_name: str,
+        include_message: bool = False,
+        statement_params: Optional[Dict[str, Any]] = None,
+    ) -> Tuple[ServiceStatus, Optional[str]]:
+        system_func = "SYSTEM$GET_SERVICE_STATUS"
+        rows = (
+            query_result_checker.SqlResultValidator(
+                self._session,
+                f"CALL {system_func}('{service_name}')",
+                statement_params=statement_params,
+            )
+            .has_dimensions(expected_rows=1, expected_cols=1)
+            .validate()
+        )
+        metadata = json.loads(rows[0][system_func])[0]
+        if metadata and metadata["status"]:
+            service_status = ServiceStatus(metadata["status"])
+            message = metadata["message"] if include_message else None
+            return service_status, message
+        return ServiceStatus.UNKNOWN, None
